package org.jeecg.modules.adweb.system.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.modules.adweb.system.service.SysAdwebApi;
import org.jeecg.modules.system.entity.SysRole;
import org.jeecg.modules.system.entity.SysUser;
import org.jeecg.modules.system.entity.SysUserRole;
import org.jeecg.modules.system.service.ISysRoleService;
import org.jeecg.modules.system.service.ISysUserRoleService;
import org.jeecg.modules.system.service.ISysUserService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @Description: 网站营销方案套餐表
 * @Author: jeecg-boot
 * @Date: 2024-09-27
 * @Version: V1.0
 */
@Tag(name = "网站营销方案套餐表")
@RestController
@RequestMapping("/adweb/system")
@Slf4j
public class SystemAdwebController {

    @Resource
    private SysAdwebApi sysAdwebApi;

    @Resource
    private ISysUserService iSysUserService;

    @Resource
    private ISysRoleService iSysRoleService;

    @Resource
    private ISysUserRoleService iSysUserRoleService;

    /**
     * 获取渠道商列表
     *
     * @return
     */
    @GetMapping("/getChannelProvider")
    public Result<?> getChannelProvider() {
        List<SysUser> userList = null;
        if (sysAdwebApi.isAdmin()) {
            //获取role表里角色编码为adweb_oem的角色的id
            List<SysRole> sysRoleList = iSysRoleService.list(new QueryWrapper<SysRole>().eq("role_code", "adweb_oem"));
            if (sysRoleList.isEmpty()) {
                return Result.error("获取渠道商列表失败");
            }
            SysRole role = sysRoleList.get(0);
            //根据adweb_oem的角色的id去查user_role中间表中所有为此角色id的user_id
            List<SysUserRole> sysUserRoleList = iSysUserRoleService.list(new QueryWrapper<SysUserRole>().eq("role_id", role.getId()));
            if (sysUserRoleList.isEmpty()) {
                return Result.error("获取渠道商列表失败");
            }
            List<String> userIdList = sysUserRoleList.stream().map(SysUserRole::getUserId).collect(Collectors.toList());
            //查询user表中所有上面查询出的user_id的数据
            userList = iSysUserService.list(new QueryWrapper<SysUser>().in("id", userIdList));
        }
        return Result.OK(userList);
    }

}
